Uses percentage coverage when base was supplied to compare_stages(),
raw record counts otherwise.
Arguments
- x
A
Stage_Comparisonobject fromcompare_stages().- ...
Passed to
tinyplot::tinyplot().
Uses percentage coverage when base was supplied to compare_stages(),
raw record counts otherwise.
A Stage_Comparison object from compare_stages().
Passed to tinyplot::tinyplot().