Extract and examine the tokens generated for a specific column
after applying the preprocessing steps defined in a Search_Strategy.
Useful for debugging and understanding how text is tokenized.
Arguments
- data
A data.frame / tibble / data.table (or db table in other backends).
- id
Character scalar naming the ID column in
data.- strategy
A
Search_Strategyobject defining preprocessing steps.- column
<
data-masked> The column to inspect.